#!/bin/bash
 
# Packager : Markus Muttilainen <stillborn.zenwalk@gmail.com>
#
# last revised : 28/07/2010
#
#package			: emesene
#homepage			: http://sourceforge.net/projects/emesene
#source location	: http://freefr.dl.sourceforge.net/project/emesene/emesene-1.6.3/emesene-1.6.3.tar.gz
#dependency         : GTK+, pygtk, python2.4 pycairo pygobject
set -e -u -x
#> log
(

softname='emesene'
softversion='1.6.3'
zenver='66.1'
arch='i486'
cpu='i686'
numjobs='-j2'

#>

buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$zenver"
dest="$buildir/$package"
source=http://freefr.dl.sourceforge.net/project/emesene/emesene-$softversion/emesene-$softversion.tar.gz
sourcetemplate=http://zenwalk.pinguix.com/user-accounts/stillborn/emesene

#>

rm -rf $dest
mkdir -p $dest/{install,usr/{bin,doc/$softname-$softversion,share/{applications,icons/hicolor/48x48/apps,$softname/{conversation_themes,libmimic}},src/$softname-$softversion}}

#> prepare slack-desc
cat <<EOF > $dest/install/slack-desc 
       |-----handy-ruler------------------------------------------------------|
emesene: emesene - Windows Live Messenger (tm) network multiplatform client
emesene:
emesene: The main idea is to make a client similar to the official MSN 
emesene: Messenger client but keeping it simple and with a nice GUI. 
emesene: Emesene is a python/gtk MSN messenger clone, it uses emesenelib
emesene: (MSNP13) and try to be a nice looking and simple MSN client.
emesene: 
emesene:
emesene:
emesene:
emesene:
EOF

#> check for sources
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#> extract sources
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
cd $buildir
tar xzvf $srcpkg

#(/usr/lib/python2.6/config/Makefile ;))
cd $src	
python setup.py build_ext -i

mv -v conversation_themes $dest/usr/share/$softname/
mv -v emesenelib $dest/usr/share/$softname/
mv -v plugins_base $dest/usr/share/$softname/
mv -v po $dest/usr/share/$softname/
mv -v smilies $dest/usr/share/$softname/
mv -v sound_themes $dest/usr/share/$softname/   
mv -v themes $dest/usr/share/$softname/
mv -v abstract $dest/usr/share/$softname
mv -v ./build/temp.linux-i686-2.6/libmimic $dest/usr/share/$softname/
mv  *.so *.py emesene $dest/usr/share/$softname/

#> prepare icon
#mv $softname-logo.png $softname.png
#convert $softname.png -resize 48x48 $softname.png
#cp -v $softname.png $dest/usr/share/icons/hicolor/48x48/apps/
inkscape -z -w48 -h48 --export-png=$dest/usr/share/icons/hicolor/48x48/apps/$softname.png $softname-logo.png

# prepare .desktop 
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Emesene
Comment=MSN Messenger client written in python and GTK
Exec=emesene
Terminal=false
Type=Application
Categories=Application;Network;
Icon=emesene
EOF

cat <<EOF > $dest/usr/bin/$softname
#!/bin/sh
exec /usr/share/$softname/$softname
EOF

chmod 755 $dest/usr/bin/$softname

#> add docs, infos, ...
(cd $src
cp -av \
      COPYING GPL LGPL PSF README \
$dest/usr/doc/$softname-$softversion
)

	
#> Strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
)

#> store buildscript 
(
cd $buildir
cp -v build-$softname.sh $dest/usr/src/$softname-$softversion
)

#> fix permissions
(
chown -R root:root $dest
cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
)

#> helperline
(cd $dest;find . -printf "%y %m %u:%g %p %l\n") >$buildir/pkgtree.log

#> do the actual zenwalk package
(
cd $dest
makepkg -l y -c n $dest.txz
)

#> prepare .src .dep .md5
cd $buildir
md5sum $package.txz > $package.md5
echo $sourcetemplate/$softname-$softversion.tar.gz > $package.src 
echo $sourcetemplate/build-$softname.sh >> $package.src
echo "gtk+2,pygtk,python,pycairo" > $package.dep

#>

rm -rf $src
rm -rf $dest


#> log
) 2>&1 | tee emesene-build.log.txt
